from ._visible import VisibleValidator
from ._uid import UidValidator
from ._tickfont import TickfontValidator
from ._stream import StreamValidator
from ._showlegend import ShowlegendValidator
from ._selectedpoints import SelectedpointsValidator
from ._rangefont import RangefontValidator
from ._opacity import OpacityValidator
from ._name import NameValidator
from ._line import LineValidator
from ._legendgroup import LegendgroupValidator
from ._labelfont import LabelfontValidator
from ._idssrc import IdssrcValidator
from ._ids import IdsValidator
from ._hoverlabel import HoverlabelValidator
from ._hoverinfosrc import HoverinfosrcValidator
from ._hoverinfo import HoverinfoValidator
from ._domain import DomainValidator
from ._dimensions import DimensionsValidator
from ._customdatasrc import CustomdatasrcValidator
from ._customdata import CustomdataValidator
