import _plotly_utils.basevalidators


class TextfontValidator(_plotly_utils.basevalidators.CompoundValidator):

    def __init__(
        self,
        plotly_name='textfont',
        parent_name='scatterpolar.selected',
        **kwargs
    ):
        super(TextfontValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            data_class_str=kwargs.pop('data_class_str', 'Textfont'),
            data_docs=kwargs.pop(
                'data_docs', """
            color
                Sets the text font color of selected points.
"""
            ),
            **kwargs
        )
