from ._zaxis import ZAxis
from plotly.graph_objs.layout.scene import zaxis
from ._yaxis import YAxis
from plotly.graph_objs.layout.scene import yaxis
from ._xaxis import XAxis
from plotly.graph_objs.layout.scene import xaxis
from ._domain import Domain
from ._camera import Camera
from plotly.graph_objs.layout.scene import camera
from ._aspectratio import Aspectratio
from ._annotation import Annotation
from plotly.graph_objs.layout.scene import annotation
